import base64

import tornado.httpserver
import tornado.ioloop
import tornado.web


class MySQLAuthMixin(object):
    """
    To implement this mixin::

        class MySQLAuthHandler(tornado.web.RequestHandler, MySQLAuthMixin):

            def post(self):
                self.get_authenticated_user(self._on_auth)

            def _on_auth(self, user):
                if not user:
                    # diplay login page again
                    self.display_login_page_with_error_message()
                self.set_current_user(user)
                print("MySQL user: %s" % user) # To see what you get
                next_url = self.get_argument("next", None) # To redirect properly
                if next_url:
                    self.redirect(next_url)
                else:
                    self.redirect("/")
    """
    
    def initialize(self):
        """
        Print out helpful error messages if the requisite settings aren't
        configured.
        """
        self.require_setting("mysql_address", _("MySQL Server Address"))
        self.require_setting("mysql_port", _("MySQL Server Port"))

    def get_authenticated_user(self, callback):
        username = self.get_argument("username", "")
        password = self.get_argument("password", "")
        
        # TODO: authenticate username-password pair
        authenticated = True
        if authenticated:
            # authentication success
            user = {"username": username, "password": password}
        else:
            user = None
        callback(user)
    
    def set_current_user(self, user):
        self.set_secure_cookie("user", tornado.escape.json_encode(user))
    
    def get_current_user(self):
        user = self.get_secure_cookie("user")
        if user:
            try:
                return tornado.escape.json_decode(user)
            except:
                return None
        return None
    